.. _utilipy-decorators:

*********************************
Decorators (`utilipy.decorators`)
*********************************

.. currentmodule:: utilipy.decorators



Reference/API
=============

.. automodapi:: utilipy.decorators
	:include-all-objects:
	:skip: wraps


Submodules
----------

.. toctree::
   :maxdepth: 1

   baseclass
   docstring
   func_io
